## 0.0.11 - 2022-03-14

### Added

- [#296](https://github.com/edgarrmondragon/citric/pull/296) Implement `set_group_properties`, `set_language_properties`, `set_participant_properties`, `set_question_properties`, `set_survey_properties` in client
